# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litepie/company/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/litepie/company/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Litepie\\Company\\": "packages/litepie/company/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litepie\Company\Providers\CompanyServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Company'  => Litepie\Company\Facades\Company::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litepie\\CompanyTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litepie\Company\Providers\CompanyServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litepie\Company\Providers\CompanyServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litepie\Company\Providers\CompanyServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/company/{modulename}

**User**

    http://path-to-route-folder/user/company/{modulename}

**Public**

    http://path-to-route-folder/companies


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/company/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/company/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/company/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/company/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/company/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/company/{modulename}/{slug}
    METHOD: GET