<?php

namespace Litepie\Company\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Litepie\Company\Http\Requests\RoleRequest;
use Litepie\Company\Interfaces\RoleRepositoryInterface;
use Litepie\Company\Models\Role;
use Litepie\Company\Forms\Role as Form;

/**
 * APIController  class for role.
 */
class RoleAPIController extends BaseController
{

    /**
     * Initialize role resource controller.
     *
     * @param type RoleRepositoryInterface $role
     *
     * @return null
     */
    public function __construct(RoleRepositoryInterface $role)
    {
        parent::__construct();
        $this->repository = $role;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Company\Repositories\Criteria\RoleResourceCriteria::class);
    }

    /**
     * Display a list of role.
     *
     * @return Response
     */
    public function index(RoleRequest $request)
    {
        return $this->repository
            ->setPresenter(\Litepie\Company\Repositories\Presenter\RolePresenter::class)
            ->paginate();
    }

    /**
     * Display role.
     *
     * @param Request $request
     * @param Model   $role
     *
     * @return Response
     */
    public function show(RoleRequest $request, Role $role)
    {
        return $role->setPresenter(\Litepie\Company\Repositories\Presenter\RoleListPresenter::class);
        ;
    }

    /**
     * Create new role.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(RoleRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('company::role.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('company/role/' . $role->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('company/role');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the role.
     *
     * @param Request $request
     * @param Model   $role
     *
     * @return Response
     */
    public function update(RoleRequest $request, Role $role)
    {
        try {
            $data = $request->all();

            $role->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('company::role.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('company/role/' . $role->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('company/role/' . $role->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the role.
     *
     * @param Model   $role
     *
     * @return Response
     */
    public function destroy(RoleRequest $request, Role $role)
    {
        try {
            $role->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('company::role.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('company/role/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('company/role/' . $role->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
