<?php

namespace Litepie\Company\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Company\Models\Role;

class RolePolicy
{

    /**
     * Determine if the given user can view the role.
     *
     * @param UserPolicy $user
     * @param Role $role
     *
     * @return bool
     */
    public function view(UserPolicy $user, Role $role)
    {
        if ($user->canDo('company.role.view') && $user->isAdmin()) {
            return true;
        }

        return $role->user_id == user_id() && $role->user_type == user_type();
    }

    /**
     * Determine if the given user can create a role.
     *
     * @param UserPolicy $user
     * @param Role $role
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('company.role.create');
    }

    /**
     * Determine if the given user can update the given role.
     *
     * @param UserPolicy $user
     * @param Role $role
     *
     * @return bool
     */
    public function update(UserPolicy $user, Role $role)
    {
        if ($user->canDo('company.role.edit') && $user->isAdmin()) {
            return true;
        }

        return $role->user_id == user_id() && $role->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given role.
     *
     * @param UserPolicy $user
     * @param Role $role
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Role $role)
    {
        return $role->user_id == user_id() && $role->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given role.
     *
     * @param UserPolicy $user
     * @param Role $role
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Role $role)
    {
        if ($user->canDo('company.role.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given role.
     *
     * @param UserPolicy $user
     * @param Role $role
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Role $role)
    {
        if ($user->canDo('company.role.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
